@@ -6,8 +6,10 @@ from meshkernel.meshkernel import MeshKernel
 from meshkernel.py_structures import (
     AveragingMethod,
     Contacts,
+    CurvilinearParameters,
     DeleteMeshOption,
     GeometryList,
+    MakeGridParameters,
     Mesh1d,
     Mesh2d,
     Mesh2dLocation,
@@ -15,5 +17,6 @@ from meshkernel.py_structures import (
     OrthogonalizationParameters,
     ProjectToLandBoundaryOption,
     RefinementType,
+    SplinesToCurvilinearParameters,
 )
 from meshkernel.version import __version__
